summaryrefslogtreecommitdiff
path: root/chromium/net/http/http_util.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/net/http/http_util.h')
-rw-r--r--chromium/net/http/http_util.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/chromium/net/http/http_util.h b/chromium/net/http/http_util.h
index 65f64279020..86bf5c82583 100644
--- a/chromium/net/http/http_util.h
+++ b/chromium/net/http/http_util.h
@@ -96,11 +96,11 @@ class NET_EXPORT HttpUtil {
// RFC 7231).
static bool IsMethodIdempotent(base::StringPiece method);
- // Returns true if it is safe to allow users and scripts to specify the header
- // named |name|. Returns true for headers not in the list at
- // https://fetch.spec.whatwg.org/#forbidden-header-name. Does not check header
- // validity.
- static bool IsSafeHeader(base::StringPiece name);
+ // Returns true if it is safe to allow users and scripts to specify a header
+ // with a given |name| and |value|.
+ // See https://fetch.spec.whatwg.org/#forbidden-request-header.
+ // Does not check header validity.
+ static bool IsSafeHeader(base::StringPiece name, base::StringPiece value);
// Returns true if |name| is a valid HTTP header name.
static bool IsValidHeaderName(base::StringPiece name);